@@ -161,6 +161,13 @@ class BaseQuota(object):
                 raise
         return quota._info
 
+    def _network_quota_to_dict(self, network_quota):
+        if type(network_quota) is not dict:
+            dict_quota = network_quota.to_dict()
+        else:
+            dict_quota = network_quota
+        return {k: v for k, v in dict_quota.items() if v is not None}
+
     def get_network_quota(self, parsed_args):
         quota_class = (
             parsed_args.quota_class if 'quota_class' in parsed_args else False)
@@ -174,13 +181,11 @@ class BaseQuota(object):
             client = self.app.client_manager.network
             if default:
                 network_quota = client.get_quota_default(project)
-                if type(network_quota) is not dict:
-                    network_quota = network_quota.to_dict()
+                network_quota = self._network_quota_to_dict(network_quota)
             else:
                 network_quota = client.get_quota(project,
                                                  details=detail)
-                if type(network_quota) is not dict:
-                    network_quota = network_quota.to_dict()
+                network_quota = self._network_quota_to_dict(network_quota)
                 if detail:
                     # NOTE(slaweq): Neutron returns values with key "used" but
                     # Nova for example returns same data with key "in_use"
@@ -200,7 +205,7 @@ class BaseQuota(object):
 class ListQuota(command.Lister, BaseQuota):
     _description = _(
         "List quotas for all projects with non-default quota values or "
-        "list detailed quota informations for requested project")
+        "list detailed quota information for requested project")
 
     def _get_detailed_quotas(self, parsed_args):
         columns = (
@@ -225,7 +230,7 @@ class ListQuota(command.Lister, BaseQuota):
         result = []
         for resource, values in quotas.items():
             # NOTE(slaweq): there is no detailed quotas info for some resources
-            # and it should't be displayed here
+            # and it shouldn't be displayed here
             if type(values) is dict:
                 result.append({
                     'resource': resource,
@@ -528,7 +533,14 @@ class SetQuota(common.NetDetectionMixin, command.Command):
         parser.add_argument(
             '--force',
             action='store_true',
-            help=_('Force quota update (only supported by compute)')
+            help=_('Force quota update (only supported by compute and '
+                   'network)')
+        )
+        parser.add_argument(
+            '--check-limit',
+            action='store_true',
+            help=_('Check quota limit when updating (only supported by '
+                   'network)')
         )
         return parser
 
@@ -556,6 +568,11 @@ class SetQuota(common.NetDetectionMixin, command.Command):
                 volume_kwargs[k] = value
 
         network_kwargs = {}
+        if parsed_args.check_limit:
+            network_kwargs['check_limit'] = True
+        if parsed_args.force:
+            network_kwargs['force'] = True
+
         if self.app.client_manager.is_network_endpoint_enabled():
             for k, v in NETWORK_QUOTAS.items():
                 value = getattr(parsed_args, k, None)
