@@ -15,33 +15,30 @@
 
 """Service action implementations"""
 
-import argparse
-import six
+import logging
 
-from openstackclient.common import command
-from openstackclient.common import exceptions
-from openstackclient.common import utils
-from openstackclient.i18n import _  # noqa
+from osc_lib.command import command
+from osc_lib import exceptions
+from osc_lib import utils
+
+from openstackclient.i18n import _
 from openstackclient.identity import common
 
 
+LOG = logging.getLogger(__name__)
+
+
 class CreateService(command.ShowOne):
-    """Create new service"""
+    _description = _("Create new service")
 
     def get_parser(self, prog_name):
         parser = super(CreateService, self).get_parser(prog_name)
         parser.add_argument(
-            'type_or_name',
+            'type',
             metavar='<type>',
             help=_('New service type (compute, image, identity, volume, etc)'),
         )
-        type_or_name_group = parser.add_mutually_exclusive_group()
-        type_or_name_group.add_argument(
-            '--type',
-            metavar='<type>',
-            help=argparse.SUPPRESS,
-        )
-        type_or_name_group.add_argument(
+        parser.add_argument(
             '--name',
             metavar='<name>',
             help=_('New service name'),
@@ -56,56 +53,56 @@ class CreateService(command.ShowOne):
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
 
-        type_or_name = parsed_args.type_or_name
         name = parsed_args.name
         type = parsed_args.type
 
-        # If only a single positional is present, it's a <type>.
-        # This is not currently legal so it is considered a new case.
-        if not type and not name:
-            type = type_or_name
-        # If --type option is present then positional is handled as <name>;
-        # display deprecation message.
-        elif type:
-            name = type_or_name
-            self.log.warning(_('The argument --type is deprecated, use service'
-                               ' create --name <service-name> type instead.'))
-        # If --name option is present the positional is handled as <type>.
-        # Making --type optional is new, but back-compatible
-        elif name:
-            type = type_or_name
-
         service = identity_client.services.create(
             name,
             type,
-            parsed_args.description)
+            parsed_args.description,
+        )
 
         info = {}
         info.update(service._info)
-        return zip(*sorted(six.iteritems(info)))
+        return zip(*sorted(info.items()))
 
 
 class DeleteService(command.Command):
-    """Delete service"""
+    _description = _("Delete service(s)")
 
     def get_parser(self, prog_name):
         parser = super(DeleteService, self).get_parser(prog_name)
         parser.add_argument(
-            'service',
+            'services',
             metavar='<service>',
-            help=_('Service to delete (name or ID)'),
+            nargs='+',
+            help=_('Service(s) to delete (type, name or ID)'),
         )
         return parser
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
-        service = common.find_service(identity_client, parsed_args.service)
-        identity_client.services.delete(service.id)
-        return
+
+        result = 0
+        for service in parsed_args.services:
+            try:
+                service = common.find_service(identity_client, service)
+                identity_client.services.delete(service.id)
+            except Exception as e:
+                result += 1
+                LOG.error(_("Failed to delete service with "
+                          "name or ID '%(service)s': %(e)s"),
+                          {'service': service, 'e': e})
+
+        if result > 0:
+            total = len(parsed_args.services)
+            msg = (_("%(result)s of %(total)s services failed "
+                   "to delete.") % {'result': result, 'total': total})
+            raise exceptions.CommandError(msg)
 
 
 class ListService(command.Lister):
-    """List services"""
+    _description = _("List services")
 
     def get_parser(self, prog_name):
         parser = super(ListService, self).get_parser(prog_name)
@@ -131,7 +128,7 @@ class ListService(command.Lister):
 
 
 class ShowService(command.ShowOne):
-    """Display service details"""
+    _description = _("Display service details")
 
     def get_parser(self, prog_name):
         parser = super(ShowService, self).get_parser(prog_name)
@@ -155,11 +152,11 @@ class ShowService(command.ShowOne):
         if parsed_args.catalog:
             endpoints = auth_ref.service_catalog.get_endpoints(
                 service_type=parsed_args.service)
-            for (service, service_endpoints) in six.iteritems(endpoints):
+            for (service, service_endpoints) in endpoints.items():
                 if service_endpoints:
                     info = {"type": service}
                     info.update(service_endpoints[0])
-                    return zip(*sorted(six.iteritems(info)))
+                    return zip(*sorted(info.items()))
 
             msg = _("No service catalog with a type, name or ID of '%s' "
                     "exists.") % (parsed_args.service)
@@ -168,4 +165,4 @@ class ShowService(command.ShowOne):
             service = common.find_service(identity_client, parsed_args.service)
             info = {}
             info.update(service._info)
-            return zip(*sorted(six.iteritems(info)))
+            return zip(*sorted(info.items()))
