@@ -15,38 +15,45 @@
 
 """Identity v3 Credential action implementations"""
 
-import six
+import logging
 
-from openstackclient.common import command
-from openstackclient.common import utils
+from osc_lib.command import command
+from osc_lib import exceptions
+from osc_lib import utils
+
+from openstackclient.i18n import _
+from openstackclient.identity import common
+
+
+LOG = logging.getLogger(__name__)
 
 
 class CreateCredential(command.ShowOne):
-    """Create credential command"""
+    _description = _("Create new credential")
 
     def get_parser(self, prog_name):
         parser = super(CreateCredential, self).get_parser(prog_name)
         parser.add_argument(
             'user',
             metavar='<user>',
-            help='Name or ID of user that owns the credential',
+            help=_('user that owns the credential (name or ID)'),
         )
         parser.add_argument(
             '--type',
             default="cert",
             metavar='<type>',
-            choices=['ec2', 'cert'],
-            help='New credential type',
+            help=_('New credential type: cert, ec2, totp and so on'),
         )
         parser.add_argument(
             'data',
             metavar='<data>',
-            help='New credential data',
+            help=_('New credential data'),
         )
         parser.add_argument(
             '--project',
             metavar='<project>',
-            help='Project name or ID which limits the scope of the credential',
+            help=_('Project which limits the scope of '
+                   'the credential (name or ID)'),
         )
         return parser
 
@@ -66,33 +73,77 @@ class CreateCredential(command.ShowOne):
             project=project)
 
         credential._info.pop('links')
-        return zip(*sorted(six.iteritems(credential._info)))
+        return zip(*sorted(credential._info.items()))
 
 
 class DeleteCredential(command.Command):
-    """Delete credential command"""
+    _description = _("Delete credential(s)")
 
     def get_parser(self, prog_name):
         parser = super(DeleteCredential, self).get_parser(prog_name)
         parser.add_argument(
             'credential',
             metavar='<credential-id>',
-            help='ID of credential to delete',
+            nargs='+',
+            help=_('ID of credential(s) to delete'),
         )
         return parser
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
-        identity_client.credentials.delete(parsed_args.credential)
+        result = 0
+        for i in parsed_args.credential:
+            try:
+                identity_client.credentials.delete(i)
+            except Exception as e:
+                result += 1
+                LOG.error(_("Failed to delete credentials with "
+                          "ID '%(credential)s': %(e)s"),
+                          {'credential': i, 'e': e})
+
+        if result > 0:
+            total = len(parsed_args.credential)
+            msg = (_("%(result)s of %(total)s credential failed "
+                   "to delete.") % {'result': result, 'total': total})
+            raise exceptions.CommandError(msg)
 
 
 class ListCredential(command.Lister):
-    """List credential command"""
+    _description = _("List credentials")
+
+    def get_parser(self, prog_name):
+        parser = super(ListCredential, self).get_parser(prog_name)
+        parser.add_argument(
+            '--user',
+            metavar='<user>',
+            help=_('Filter credentials by <user> (name or ID)'),
+        )
+        common.add_user_domain_option_to_parser(parser)
+        parser.add_argument(
+            '--type',
+            metavar='<type>',
+            help=_('Filter credentials by type: cert, ec2, totp and so on'),
+        )
+        return parser
 
     def take_action(self, parsed_args):
+        identity_client = self.app.client_manager.identity
+
+        kwargs = {}
+        if parsed_args.user:
+            user_id = common.find_user(
+                identity_client,
+                parsed_args.user,
+                parsed_args.user_domain,
+            ).id
+            kwargs["user_id"] = user_id
+
+        if parsed_args.type:
+            kwargs["type"] = parsed_args.type
+
         columns = ('ID', 'Type', 'User ID', 'Blob', 'Project ID')
         column_headers = ('ID', 'Type', 'User ID', 'Data', 'Project ID')
-        data = self.app.client_manager.identity.credentials.list()
+        data = self.app.client_manager.identity.credentials.list(**kwargs)
         return (column_headers,
                 (utils.get_item_properties(
                     s, columns,
@@ -101,38 +152,38 @@ class ListCredential(command.Lister):
 
 
 class SetCredential(command.Command):
-    """Set credential command"""
+    _description = _("Set credential properties")
 
     def get_parser(self, prog_name):
         parser = super(SetCredential, self).get_parser(prog_name)
         parser.add_argument(
             'credential',
             metavar='<credential-id>',
-            help='ID of credential to change',
+            help=_('ID of credential to change'),
         )
         parser.add_argument(
             '--user',
             metavar='<user>',
             required=True,
-            help='Name or ID of user that owns the credential',
+            help=_('User that owns the credential (name or ID)'),
         )
         parser.add_argument(
             '--type',
             metavar='<type>',
-            choices=['ec2', 'cert'],
             required=True,
-            help='New credential type',
+            help=_('New credential type: cert, ec2, totp and so on'),
         )
         parser.add_argument(
             '--data',
             metavar='<data>',
             required=True,
-            help='New credential data',
+            help=_('New credential data'),
         )
         parser.add_argument(
             '--project',
             metavar='<project>',
-            help='Project name or ID which limits the scope of the credential',
+            help=_('Project which limits the scope of '
+                   'the credential (name or ID)'),
         )
         return parser
 
@@ -156,14 +207,14 @@ class SetCredential(command.Command):
 
 
 class ShowCredential(command.ShowOne):
-    """Show credential command"""
+    _description = _("Display credential details")
 
     def get_parser(self, prog_name):
         parser = super(ShowCredential, self).get_parser(prog_name)
         parser.add_argument(
             'credential',
             metavar='<credential-id>',
-            help='ID of credential to display',
+            help=_('ID of credential to display'),
         )
         return parser
 
@@ -173,4 +224,4 @@ class ShowCredential(command.ShowOne):
                                          parsed_args.credential)
 
         credential._info.pop('links')
-        return zip(*sorted(six.iteritems(credential._info)))
+        return zip(*sorted(credential._info.items()))
