@@ -28,7 +28,6 @@ from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import utils
 
-from openstackclient.common import sdk_utils
 from openstackclient.i18n import _
 
 if os.name == "nt":
@@ -48,15 +47,17 @@ LOG = logging.getLogger(__name__)
 
 
 def _get_columns(item):
-    # Trick sdk_utils to return URI attribute
     column_map = {
         'is_protected': 'protected',
         'owner_id': 'owner'
     }
-    hidden_columns = ['location', 'checksum',
-                      'copy_from', 'created_at', 'status', 'updated_at']
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(
-        item.to_dict(), column_map, hidden_columns)
+    hidden_columns = [
+        'location', 'checksum', 'copy_from', 'created_at', 'status',
+        'updated_at',
+    ]
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item.to_dict(), column_map, hidden_columns,
+    )
 
 
 _formatters = {
@@ -478,7 +479,11 @@ class SaveImage(command.Command):
         image_client = self.app.client_manager.image
         image = image_client.find_image(parsed_args.image)
 
-        image_client.download_image(image.id, output=parsed_args.file)
+        output_file = parsed_args.file
+        if output_file is None:
+            output_file = getattr(sys.stdout, "buffer", sys.stdout)
+
+        image_client.download_image(image.id, stream=True, output=output_file)
 
 
 class SetImage(command.Command):
