@@ -15,8 +15,10 @@
 
 import argparse
 
+from cliff import columns as cliff_columns
+from osc_lib.command import command
 from osc_lib import utils
-import six
+from osc_lib.utils import tags as _tag
 
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
@@ -29,11 +31,12 @@ def _format_network_security_group_rules(sg_rules):
     # rules, trim keys with caller known (e.g. security group and tenant ID)
     # or empty values.
     for sg_rule in sg_rules:
-        empty_keys = [k for k, v in six.iteritems(sg_rule) if not v]
+        empty_keys = [k for k, v in sg_rule.items() if not v]
         for key in empty_keys:
             sg_rule.pop(key)
         sg_rule.pop('security_group_id', None)
         sg_rule.pop('tenant_id', None)
+        sg_rule.pop('project_id', None)
     return utils.format_list_of_dicts(sg_rules)
 
 
@@ -61,41 +64,45 @@ def _format_compute_security_group_rules(sg_rules):
     return utils.format_list(rules, separator='\n')
 
 
+class NetworkSecurityGroupRulesColumn(cliff_columns.FormattableColumn):
+    def human_readable(self):
+        return _format_network_security_group_rules(self._value)
+
+
+class ComputeSecurityGroupRulesColumn(cliff_columns.FormattableColumn):
+    def human_readable(self):
+        return _format_compute_security_group_rules(self._value)
+
+
 _formatters_network = {
-    'security_group_rules': _format_network_security_group_rules,
+    'security_group_rules': NetworkSecurityGroupRulesColumn,
 }
 
 
 _formatters_compute = {
-    'rules': _format_compute_security_group_rules,
+    'rules': ComputeSecurityGroupRulesColumn,
 }
 
 
 def _get_columns(item):
-    # Build the display columns and a list of the property columns
-    # that need to be mapped (display column name, property name).
-    columns = list(item.keys())
-    property_column_mappings = []
-    if 'security_group_rules' in columns:
-        columns.append('rules')
-        columns.remove('security_group_rules')
-        property_column_mappings.append(('rules', 'security_group_rules'))
-    if 'tenant_id' in columns:
-        columns.append('project_id')
-        columns.remove('tenant_id')
-        property_column_mappings.append(('project_id', 'tenant_id'))
-    display_columns = sorted(columns)
-
-    # Build the property columns and apply any column mappings.
-    property_columns = sorted(columns)
-    for property_column_mapping in property_column_mappings:
-        property_index = property_columns.index(property_column_mapping[0])
-        property_columns[property_index] = property_column_mapping[1]
-    return tuple(display_columns), property_columns
+    # We still support Nova managed security groups, where we have tenant_id.
+    column_map = {
+        'security_group_rules': 'rules',
+        'tenant_id': 'project_id',
+    }
+    hidden_columns = ['location']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item,
+        column_map,
+        hidden_columns
+    )
 
 
-class CreateSecurityGroup(common.NetworkAndComputeShowOne):
-    """Create a new security group"""
+# TODO(abhiraut): Use the SDK resource mapped attribute names once the
+# OSC minimum requirements include SDK 1.0.
+class CreateSecurityGroup(common.NetworkAndComputeShowOne,
+                          common.NeutronCommandWithExtraArgs):
+    _description = _("Create a new security group")
 
     def update_parser_common(self, parser):
         parser.add_argument(
@@ -114,9 +121,26 @@ class CreateSecurityGroup(common.NetworkAndComputeShowOne):
         parser.add_argument(
             '--project',
             metavar='<project>',
-            help=_("Owner's project (name or ID)")
+            help=self.enhance_help_neutron(_("Owner's project (name or ID)"))
         )
-        identity_common.add_project_domain_option_to_parser(parser)
+        stateful_group = parser.add_mutually_exclusive_group()
+        stateful_group.add_argument(
+            "--stateful",
+            action='store_true',
+            default=None,
+            help=_("Security group is stateful (Default)")
+        )
+        stateful_group.add_argument(
+            "--stateless",
+            action='store_true',
+            default=None,
+            help=_("Security group is stateless")
+        )
+        identity_common.add_project_domain_option_to_parser(
+            parser, enhance_help=self.enhance_help_neutron)
+        _tag.add_tag_option_to_parser_for_create(
+            parser, _('security group'),
+            enhance_help=self.enhance_help_neutron)
         return parser
 
     def _get_description(self, parsed_args):
@@ -130,6 +154,10 @@ class CreateSecurityGroup(common.NetworkAndComputeShowOne):
         attrs = {}
         attrs['name'] = parsed_args.name
         attrs['description'] = self._get_description(parsed_args)
+        if parsed_args.stateful:
+            attrs['stateful'] = True
+        if parsed_args.stateless:
+            attrs['stateful'] = False
         if parsed_args.project is not None:
             identity_client = self.app.client_manager.identity
             project_id = identity_common.find_project(
@@ -137,10 +165,14 @@ class CreateSecurityGroup(common.NetworkAndComputeShowOne):
                 parsed_args.project,
                 parsed_args.project_domain,
             ).id
-            attrs['tenant_id'] = project_id
+            attrs['project_id'] = project_id
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
 
         # Create the security group and display the results.
         obj = client.create_security_group(**attrs)
+        # tags cannot be set when created, so tags need to be set later.
+        _tag.update_tags_for_set(client, obj, parsed_args)
         display_columns, property_columns = _get_columns(obj)
         data = utils.get_item_properties(
             obj,
@@ -151,13 +183,13 @@ class CreateSecurityGroup(common.NetworkAndComputeShowOne):
 
     def take_action_compute(self, client, parsed_args):
         description = self._get_description(parsed_args)
-        obj = client.security_groups.create(
+        obj = client.api.security_group_create(
             parsed_args.name,
             description,
         )
-        display_columns, property_columns = _get_columns(obj._info)
+        display_columns, property_columns = _get_columns(obj)
         data = utils.get_dict_properties(
-            obj._info,
+            obj,
             property_columns,
             formatters=_formatters_compute
         )
@@ -165,7 +197,7 @@ class CreateSecurityGroup(common.NetworkAndComputeShowOne):
 
 
 class DeleteSecurityGroup(common.NetworkAndComputeDelete):
-    """Delete security group(s)"""
+    _description = _("Delete security group(s)")
 
     # Used by base class to find resources in parsed_args.
     resource = 'group'
@@ -185,22 +217,38 @@ class DeleteSecurityGroup(common.NetworkAndComputeDelete):
         client.delete_security_group(obj)
 
     def take_action_compute(self, client, parsed_args):
-        data = utils.find_resource(client.security_groups, self.r)
-        client.security_groups.delete(data.id)
+        client.api.security_group_delete(self.r)
 
 
+# TODO(rauta): Use the SDK resource mapped attribute names once
+# the OSC minimum requirements include SDK 1.0.
 class ListSecurityGroup(common.NetworkAndComputeLister):
-    """List security groups"""
+    _description = _("List security groups")
+    FIELDS_TO_RETRIEVE = ['id', 'name', 'description', 'project_id', 'tags']
 
     def update_parser_network(self, parser):
-        # Maintain and hide the argument for backwards compatibility.
-        # Network will always return all projects for an admin.
+        if not self.is_docs_build:
+            # Maintain and hide the argument for backwards compatibility.
+            # Network will always return all projects for an admin.
+            parser.add_argument(
+                '--all-projects',
+                action='store_true',
+                default=False,
+                help=argparse.SUPPRESS,
+            )
+
         parser.add_argument(
-            '--all-projects',
-            action='store_true',
-            default=False,
-            help=argparse.SUPPRESS,
+            '--project',
+            metavar='<project>',
+            help=self.enhance_help_neutron(
+                _("List security groups according to the project (name or "
+                  "ID)"))
         )
+        identity_common.add_project_domain_option_to_parser(
+            parser, enhance_help=self.enhance_help_neutron)
+        _tag.add_tag_filtering_option_to_parser(
+            parser, _('security group'),
+            enhance_help=self.enhance_help_neutron)
         return parser
 
     def update_parser_compute(self, parser):
@@ -208,37 +256,70 @@ class ListSecurityGroup(common.NetworkAndComputeLister):
             '--all-projects',
             action='store_true',
             default=False,
-            help=_("Display information from all projects (admin only)")
+            help=self.enhance_help_nova_network(
+                _("Display information from all projects (admin only)"))
         )
         return parser
 
-    def _get_return_data(self, data, include_project=True):
+    def take_action_network(self, client, parsed_args):
+        filters = {}
+        if parsed_args.project:
+            identity_client = self.app.client_manager.identity
+            project_id = identity_common.find_project(
+                identity_client,
+                parsed_args.project,
+                parsed_args.project_domain,
+            ).id
+            filters['project_id'] = project_id
+
+        _tag.get_tag_filtering_args(parsed_args, filters)
+        data = client.security_groups(fields=self.FIELDS_TO_RETRIEVE,
+                                      **filters)
+
+        columns = (
+            "ID",
+            "Name",
+            "Description",
+            "Project ID",
+            "tags"
+        )
+        column_headers = (
+            "ID",
+            "Name",
+            "Description",
+            "Project",
+            "Tags"
+        )
+        return (column_headers,
+                (utils.get_item_properties(
+                    s, columns,
+                ) for s in data))
+
+    def take_action_compute(self, client, parsed_args):
+        search = {'all_tenants': parsed_args.all_projects}
+        data = client.api.security_group_list(
+            # TODO(dtroyer): add limit, marker
+            search_opts=search,
+        )
+
         columns = (
             "ID",
             "Name",
             "Description",
         )
         column_headers = columns
-        if include_project:
+        if parsed_args.all_projects:
             columns = columns + ('Tenant ID',)
             column_headers = column_headers + ('Project',)
         return (column_headers,
-                (utils.get_item_properties(
+                (utils.get_dict_properties(
                     s, columns,
                 ) for s in data))
 
-    def take_action_network(self, client, parsed_args):
-        return self._get_return_data(client.security_groups())
 
-    def take_action_compute(self, client, parsed_args):
-        search = {'all_tenants': parsed_args.all_projects}
-        data = client.security_groups.list(search_opts=search)
-        return self._get_return_data(data,
-                                     include_project=parsed_args.all_projects)
-
-
-class SetSecurityGroup(common.NetworkAndComputeCommand):
-    """Set security group properties"""
+class SetSecurityGroup(common.NetworkAndComputeCommand,
+                       common.NeutronCommandWithExtraArgs):
+    _description = _("Set security group properties")
 
     def update_parser_common(self, parser):
         parser.add_argument(
@@ -256,6 +337,25 @@ class SetSecurityGroup(common.NetworkAndComputeCommand):
             metavar="<description>",
             help=_("New security group description")
         )
+        stateful_group = parser.add_mutually_exclusive_group()
+        stateful_group.add_argument(
+            "--stateful",
+            action='store_true',
+            default=None,
+            help=_("Security group is stateful (Default)")
+        )
+        stateful_group.add_argument(
+            "--stateless",
+            action='store_true',
+            default=None,
+            help=_("Security group is stateless")
+        )
+        return parser
+
+    def update_parser_network(self, parser):
+        _tag.add_tag_option_to_parser_for_set(
+            parser, _('security group'),
+            enhance_help=self.enhance_help_neutron)
         return parser
 
     def take_action_network(self, client, parsed_args):
@@ -266,34 +366,40 @@ class SetSecurityGroup(common.NetworkAndComputeCommand):
             attrs['name'] = parsed_args.name
         if parsed_args.description is not None:
             attrs['description'] = parsed_args.description
+        if parsed_args.stateful:
+            attrs['stateful'] = True
+        if parsed_args.stateless:
+            attrs['stateful'] = False
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
         # NOTE(rtheis): Previous behavior did not raise a CommandError
         # if there were no updates. Maintain this behavior and issue
         # the update.
         client.update_security_group(obj, **attrs)
 
+        # tags is a subresource and it needs to be updated separately.
+        _tag.update_tags_for_set(client, obj, parsed_args)
+
     def take_action_compute(self, client, parsed_args):
-        data = utils.find_resource(
-            client.security_groups,
-            parsed_args.group,
-        )
+        data = client.api.security_group_find(parsed_args.group)
 
         if parsed_args.name is not None:
-            data.name = parsed_args.name
+            data['name'] = parsed_args.name
         if parsed_args.description is not None:
-            data.description = parsed_args.description
+            data['description'] = parsed_args.description
 
         # NOTE(rtheis): Previous behavior did not raise a CommandError
         # if there were no updates. Maintain this behavior and issue
         # the update.
-        client.security_groups.update(
+        client.api.security_group_set(
             data,
-            data.name,
-            data.description,
+            data['name'],
+            data['description'],
         )
 
 
 class ShowSecurityGroup(common.NetworkAndComputeShowOne):
-    """Display security group details"""
+    _description = _("Display security group details")
 
     def update_parser_common(self, parser):
         parser.add_argument(
@@ -315,14 +421,33 @@ class ShowSecurityGroup(common.NetworkAndComputeShowOne):
         return (display_columns, data)
 
     def take_action_compute(self, client, parsed_args):
-        obj = utils.find_resource(
-            client.security_groups,
-            parsed_args.group,
-        )
-        display_columns, property_columns = _get_columns(obj._info)
+        obj = client.api.security_group_find(parsed_args.group)
+        display_columns, property_columns = _get_columns(obj)
         data = utils.get_dict_properties(
-            obj._info,
+            obj,
             property_columns,
             formatters=_formatters_compute
         )
         return (display_columns, data)
+
+
+class UnsetSecurityGroup(command.Command):
+    _description = _("Unset security group properties")
+
+    def get_parser(self, prog_name):
+        parser = super(UnsetSecurityGroup, self).get_parser(prog_name)
+        parser.add_argument(
+            'group',
+            metavar="<group>",
+            help=_("Security group to modify (name or ID)")
+        )
+        _tag.add_tag_option_to_parser_for_unset(parser, _('security group'))
+        return parser
+
+    def take_action(self, parsed_args):
+        client = self.app.client_manager.network
+        obj = client.find_security_group(parsed_args.group,
+                                         ignore_missing=False)
+
+        # tags is a subresource and it needs to be updated separately.
+        _tag.update_tags_for_unset(client, obj, parsed_args)
