@@ -16,16 +16,17 @@
 import copy
 import logging
 
+from cliff import columns as cliff_columns
+from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
+from osc_lib.utils import tags as _tag
 
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
-from openstackclient.network import sdk_utils
-from openstackclient.network.v2 import _tag
-
+from openstackclient.network import common
 
 LOG = logging.getLogger(__name__)
 
@@ -40,23 +41,27 @@ def _update_arguments(obj_list, parsed_args_list, option):
             raise exceptions.CommandError(msg)
 
 
-def _format_allocation_pools(data):
-    pool_formatted = ['%s-%s' % (pool.get('start', ''), pool.get('end', ''))
-                      for pool in data]
-    return ','.join(pool_formatted)
+class AllocationPoolsColumn(cliff_columns.FormattableColumn):
+    def human_readable(self):
+        pool_formatted = ['%s-%s' % (pool.get('start', ''),
+                                     pool.get('end', ''))
+                          for pool in self._value]
+        return ','.join(pool_formatted)
 
 
-def _format_host_routes(data):
-    # Map the host route keys to match --host-route option.
-    return utils.format_list_of_dicts(convert_entries_to_gateway(data))
+class HostRoutesColumn(cliff_columns.FormattableColumn):
+    def human_readable(self):
+        # Map the host route keys to match --host-route option.
+        return utils.format_list_of_dicts(
+            convert_entries_to_gateway(self._value))
 
 
 _formatters = {
-    'allocation_pools': _format_allocation_pools,
-    'dns_nameservers': utils.format_list,
-    'host_routes': _format_host_routes,
-    'service_types': utils.format_list,
-    'tags': utils.format_list,
+    'allocation_pools': AllocationPoolsColumn,
+    'dns_nameservers': format_columns.ListColumn,
+    'host_routes': HostRoutesColumn,
+    'service_types': format_columns.ListColumn,
+    'tags': format_columns.ListColumn,
 }
 
 
@@ -132,14 +137,18 @@ def _get_columns(item):
     column_map = {
         'is_dhcp_enabled': 'enable_dhcp',
         'subnet_pool_id': 'subnetpool_id',
-        'tenant_id': 'project_id',
     }
-    # Do not show this column when displaying a subnet
-    invisible_columns = ['use_default_subnet_pool']
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(
+    # Do not show these columns when displaying a subnet
+    hidden_columns = [
+        'location',
+        'use_default_subnet_pool',
+        'prefix_length',
+        'tenant_id',
+    ]
+    return utils.get_osc_show_columns_for_sdk_resource(
         item,
         column_map,
-        invisible_columns=invisible_columns
+        hidden_columns
     )
 
 
@@ -169,7 +178,7 @@ def _get_attrs(client_manager, parsed_args, is_create=True):
     attrs = {}
     client = client_manager.network
     if 'name' in parsed_args and parsed_args.name is not None:
-        attrs['name'] = str(parsed_args.name)
+        attrs['name'] = parsed_args.name
 
     if is_create:
         if 'project' in parsed_args and parsed_args.project is not None:
@@ -179,7 +188,7 @@ def _get_attrs(client_manager, parsed_args, is_create=True):
                 parsed_args.project,
                 parsed_args.project_domain,
             ).id
-            attrs['tenant_id'] = project_id
+            attrs['project_id'] = project_id
         attrs['network_id'] = client.find_network(parsed_args.network,
                                                   ignore_missing=False).id
         if parsed_args.subnet_pool is not None:
@@ -223,6 +232,10 @@ def _get_attrs(client_manager, parsed_args, is_create=True):
         attrs['enable_dhcp'] = True
     if parsed_args.no_dhcp:
         attrs['enable_dhcp'] = False
+    if parsed_args.dns_publish_fixed_ip:
+        attrs['dns_publish_fixed_ip'] = True
+    if parsed_args.no_dns_publish_fixed_ip:
+        attrs['dns_publish_fixed_ip'] = False
     if ('dns_nameservers' in parsed_args and
        parsed_args.dns_nameservers is not None):
         attrs['dns_nameservers'] = parsed_args.dns_nameservers
@@ -240,13 +253,14 @@ def _get_attrs(client_manager, parsed_args, is_create=True):
 
 # TODO(abhiraut): Use the SDK resource mapped attribute names once the
 # OSC minimum requirements include SDK 1.0.
-class CreateSubnet(command.ShowOne):
+class CreateSubnet(command.ShowOne, common.NeutronCommandWithExtraArgs):
     _description = _("Create a subnet")
 
     def get_parser(self, prog_name):
         parser = super(CreateSubnet, self).get_parser(prog_name)
         parser.add_argument(
             'name',
+            metavar='<name>',
             help=_("New subnet name")
         )
         parser.add_argument(
@@ -295,6 +309,17 @@ class CreateSubnet(command.ShowOne):
             action='store_true',
             help=_("Disable DHCP")
         )
+        dns_publish_fixed_ip_group = parser.add_mutually_exclusive_group()
+        dns_publish_fixed_ip_group.add_argument(
+            '--dns-publish-fixed-ip',
+            action='store_true',
+            help=_("Enable publishing fixed IPs in DNS")
+        )
+        dns_publish_fixed_ip_group.add_argument(
+            '--no-dns-publish-fixed-ip',
+            action='store_true',
+            help=_("Disable publishing fixed IPs in DNS (default)")
+        )
         parser.add_argument(
             '--gateway',
             metavar='<gateway>',
@@ -351,6 +376,8 @@ class CreateSubnet(command.ShowOne):
     def take_action(self, parsed_args):
         client = self.app.client_manager.network
         attrs = _get_attrs(self.app.client_manager, parsed_args)
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
         obj = client.create_subnet(**attrs)
         # tags cannot be set when created, so tags need to be set later.
         _tag.update_tags_for_set(client, obj, parsed_args)
@@ -412,7 +439,7 @@ class ListSubnet(command.Lister):
             choices=[4, 6],
             metavar='<ip-version>',
             dest='ip_version',
-            help=_("List only subnets of given IP version in output."
+            help=_("List only subnets of given IP version in output. "
                    "Allowed values for IP version are 4 and 6."),
         )
         dhcp_enable_group = parser.add_mutually_exclusive_group()
@@ -466,6 +493,12 @@ class ListSubnet(command.Lister):
                    "(in CIDR notation) in output "
                    "e.g.: --subnet-range 10.10.0.0/16")
         )
+        parser.add_argument(
+            '--subnet-pool',
+            metavar='<subnet-pool>',
+            help=_("List only subnets which belong to a given subnet pool "
+                   "in output (Name or ID)")
+        )
         _tag.add_tag_filtering_option_to_parser(parser, _('subnets'))
         return parser
 
@@ -489,7 +522,6 @@ class ListSubnet(command.Lister):
                 parsed_args.project,
                 parsed_args.project_domain,
             ).id
-            filters['tenant_id'] = project_id
             filters['project_id'] = project_id
         if parsed_args.network:
             network_id = network_client.find_network(parsed_args.network,
@@ -501,6 +533,10 @@ class ListSubnet(command.Lister):
             filters['name'] = parsed_args.name
         if parsed_args.subnet_range:
             filters['cidr'] = parsed_args.subnet_range
+        if parsed_args.subnet_pool:
+            subnetpool_id = network_client.find_subnet_pool(
+                parsed_args.subnet_pool, ignore_missing=False).id
+            filters['subnetpool_id'] = subnetpool_id
         _tag.get_tag_filtering_args(parsed_args, filters)
         data = network_client.subnets(**filters)
 
@@ -523,7 +559,7 @@ class ListSubnet(command.Lister):
 
 # TODO(abhiraut): Use the SDK resource mapped attribute names once the
 # OSC minimum requirements include SDK 1.0.
-class SetSubnet(command.Command):
+class SetSubnet(common.NeutronCommandWithExtraArgs):
     _description = _("Set subnet properties")
 
     def get_parser(self, prog_name):
@@ -550,6 +586,17 @@ class SetSubnet(command.Command):
             action='store_true',
             help=_("Disable DHCP")
         )
+        dns_publish_fixed_ip_group = parser.add_mutually_exclusive_group()
+        dns_publish_fixed_ip_group.add_argument(
+            '--dns-publish-fixed-ip',
+            action='store_true',
+            help=_("Enable publishing fixed IPs in DNS")
+        )
+        dns_publish_fixed_ip_group.add_argument(
+            '--no-dns-publish-fixed-ip',
+            action='store_true',
+            help=_("Disable publishing fixed IPs in DNS")
+        )
         parser.add_argument(
             '--gateway',
             metavar='<gateway>',
@@ -597,6 +644,8 @@ class SetSubnet(command.Command):
             attrs['allocation_pools'] = []
         if 'service_types' in attrs:
             attrs['service_types'] += obj.service_types
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
         if attrs:
             client.update_subnet(obj, **attrs)
         # tags is a subresource and it needs to be updated separately.
@@ -624,7 +673,7 @@ class ShowSubnet(command.ShowOne):
         return (display_columns, data)
 
 
-class UnsetSubnet(command.Command):
+class UnsetSubnet(common.NeutronUnsetCommandWithExtraArgs):
     _description = _("Unset subnet properties")
 
     def get_parser(self, prog_name):
@@ -639,6 +688,11 @@ class UnsetSubnet(command.Command):
                    'subnet e.g.: start=192.168.199.2,end=192.168.199.254 '
                    '(repeat option to unset multiple allocation pools)')
         )
+        parser.add_argument(
+            '--gateway',
+            action='store_true',
+            help=_("Remove gateway IP from this subnet")
+        )
         parser.add_argument(
             '--dns-nameserver',
             metavar='<dns-nameserver>',
@@ -680,29 +734,35 @@ class UnsetSubnet(command.Command):
     def take_action(self, parsed_args):
         client = self.app.client_manager.network
         obj = client.find_subnet(parsed_args.subnet, ignore_missing=False)
-        tmp_obj = copy.deepcopy(obj)
+
         attrs = {}
+        if parsed_args.gateway:
+            attrs['gateway_ip'] = None
         if parsed_args.dns_nameservers:
-            _update_arguments(tmp_obj.dns_nameservers,
+            attrs['dns_nameservers'] = copy.deepcopy(obj.dns_nameservers)
+            _update_arguments(attrs['dns_nameservers'],
                               parsed_args.dns_nameservers,
                               'dns-nameserver')
-            attrs['dns_nameservers'] = tmp_obj.dns_nameservers
         if parsed_args.host_routes:
+            attrs['host_routes'] = copy.deepcopy(obj.host_routes)
             _update_arguments(
-                tmp_obj.host_routes,
+                attrs['host_routes'],
                 convert_entries_to_nexthop(parsed_args.host_routes),
                 'host-route')
-            attrs['host_routes'] = tmp_obj.host_routes
         if parsed_args.allocation_pools:
-            _update_arguments(tmp_obj.allocation_pools,
+            attrs['allocation_pools'] = copy.deepcopy(obj.allocation_pools)
+            _update_arguments(attrs['allocation_pools'],
                               parsed_args.allocation_pools,
                               'allocation-pool')
-            attrs['allocation_pools'] = tmp_obj.allocation_pools
+
         if parsed_args.service_types:
-            _update_arguments(tmp_obj.service_types,
+            attrs['service_types'] = copy.deepcopy(obj.service_types)
+            _update_arguments(attrs['service_types'],
                               parsed_args.service_types,
                               'service-type')
-            attrs['service_types'] = tmp_obj.service_types
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
+
         if attrs:
             client.update_subnet(obj, **attrs)
 
