@@ -10,6 +10,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import logging
 import os
 import shlex
 import subprocess
@@ -18,22 +19,30 @@ from tempest.lib.cli import output_parser
 from tempest.lib import exceptions
 import testtools
 
-
 ADMIN_CLOUD = os.environ.get('OS_ADMIN_CLOUD', 'devstack-admin')
+LOG = logging.getLogger(__name__)
 
 
 def execute(cmd, fail_ok=False, merge_stderr=False):
     """Executes specified command for the given action."""
+    LOG.debug('Executing: %s', cmd)
     cmdlist = shlex.split(cmd)
     stdout = subprocess.PIPE
     stderr = subprocess.STDOUT if merge_stderr else subprocess.PIPE
+
     proc = subprocess.Popen(cmdlist, stdout=stdout, stderr=stderr)
-    result, result_err = proc.communicate()
-    result = result.decode('utf-8')
+
+    result_out, result_err = proc.communicate()
+    result_out = result_out.decode('utf-8')
+    LOG.debug('stdout: %s', result_out)
+    LOG.debug('stderr: %s', result_err)
+
     if not fail_ok and proc.returncode != 0:
-        raise exceptions.CommandFailed(proc.returncode, cmd, result,
-                                       result_err)
-    return result
+        raise exceptions.CommandFailed(
+            proc.returncode, cmd, result_out, result_err,
+        )
+
+    return result_out
 
 
 class TestCase(testtools.TestCase):
@@ -42,7 +51,7 @@ class TestCase(testtools.TestCase):
     def openstack(cls, cmd, cloud=ADMIN_CLOUD, fail_ok=False):
         """Executes openstackclient command for the given action
 
-        NOTE(dtroyer): There is a subtle distinction between pasing
+        NOTE(dtroyer): There is a subtle distinction between passing
         cloud=None and cloud='': for compatibility reasons passing
         cloud=None continues to include the option '--os-auth-type none'
         in the command while passing cloud='' omits the '--os-auth-type'
@@ -61,24 +70,31 @@ class TestCase(testtools.TestCase):
                 fail_ok=fail_ok
             )
         else:
-            # Execure command with an explicit cloud specified
+            # Execute command with an explicit cloud specified
             return execute(
                 'openstack --os-cloud=' + cloud + ' ' + cmd,
                 fail_ok=fail_ok
             )
 
     @classmethod
-    def is_service_enabled(cls, service):
-        """Ask client cloud if service is available"""
-        cmd = ('service show -f value -c enabled {service}'
-               .format(service=service))
-        try:
-            return "True" in cls.openstack(cmd)
-        except exceptions.CommandFailed as e:
-            if "No service with a type, name or ID of" in str(e):
-                return False
-            else:
-                raise  # Unable to determine if service is enabled
+    def is_service_enabled(cls, service, version=None):
+        """Ask client cloud if service is available
+
+        :param service: The service name or type. This should be either an
+            exact match to what is in the catalog or a known official value or
+            alias from service-types-authority
+        :param version: Optional version. This should be a major version, e.g.
+            '2.0'
+        :returns: True if the service is enabled and optionally provides the
+            specified API version, else False
+        """
+        ret = cls.openstack(
+            f'versions show --service {service} -f value -c Version'
+        ).splitlines()
+        if version:
+            return version in ret
+
+        return bool(ret)
 
     @classmethod
     def is_extension_enabled(cls, alias):
