@@ -13,7 +13,7 @@
 #   under the License.
 #
 
-import mock
+from unittest import mock
 
 from keystoneauth1 import exceptions as ks_exc
 from osc_lib.cli import format_columns
@@ -643,7 +643,7 @@ class TestProjectShow(TestProject):
             self.fake_proj_show.name,
             format_columns.DictColumn({}),
         )
-        self.assertItemEqual(datalist, data)
+        self.assertCountEqual(datalist, data)
 
 
 class TestProjectUnset(TestProject):
