@@ -26,6 +26,10 @@ from openstackclient.tests.unit.network.v2 import fakes as network_fakes
 from openstackclient.tests.unit import utils as tests_utils
 
 
+LIST_FIELDS_TO_RETRIEVE = ('id', 'name', 'mac_address', 'fixed_ips', 'status')
+LIST_FIELDS_TO_RETRIEVE_LONG = ('security_group_ids', 'device_owner', 'tags')
+
+
 class TestPort(network_fakes.TestNetworkV2):
 
     def setUp(self):
@@ -46,60 +50,74 @@ class TestPort(network_fakes.TestNetworkV2):
             'binding_vif_details',
             'binding_vif_type',
             'binding_vnic_type',
+            'created_at',
             'data_plane_status',
             'description',
             'device_id',
             'device_owner',
+            'device_profile',
             'dns_assignment',
             'dns_domain',
             'dns_name',
             'extra_dhcp_opts',
             'fixed_ips',
             'id',
+            'ip_allocation',
             'mac_address',
             'name',
             'network_id',
             'numa_affinity_policy',
             'port_security_enabled',
             'project_id',
+            'propagate_uplink_status',
+            'resource_request',
+            'revision_number',
             'qos_network_policy_id',
             'qos_policy_id',
             'security_group_ids',
             'status',
             'tags',
-            'uplink_status_propagation',
+            'trunk_details',
+            'updated_at',
         )
 
         data = (
-            port.AdminStateColumn(fake_port.admin_state_up),
+            port.AdminStateColumn(fake_port.is_admin_state_up),
             format_columns.ListDictColumn(fake_port.allowed_address_pairs),
             fake_port.binding_host_id,
             format_columns.DictColumn(fake_port.binding_profile),
             format_columns.DictColumn(fake_port.binding_vif_details),
             fake_port.binding_vif_type,
             fake_port.binding_vnic_type,
+            fake_port.created_at,
             fake_port.data_plane_status,
             fake_port.description,
             fake_port.device_id,
             fake_port.device_owner,
+            fake_port.device_profile,
             format_columns.ListDictColumn(fake_port.dns_assignment),
             fake_port.dns_domain,
             fake_port.dns_name,
             format_columns.ListDictColumn(fake_port.extra_dhcp_opts),
             format_columns.ListDictColumn(fake_port.fixed_ips),
             fake_port.id,
+            fake_port.ip_allocation,
             fake_port.mac_address,
             fake_port.name,
             fake_port.network_id,
             fake_port.numa_affinity_policy,
-            fake_port.port_security_enabled,
+            fake_port.is_port_security_enabled,
             fake_port.project_id,
+            fake_port.propagate_uplink_status,
+            fake_port.resource_request,
+            fake_port.revision_number,
             fake_port.qos_network_policy_id,
             fake_port.qos_policy_id,
             format_columns.ListColumn(fake_port.security_group_ids),
             fake_port.status,
             format_columns.ListColumn(fake_port.tags),
-            fake_port.uplink_status_propagation,
+            fake_port.trunk_details,
+            fake_port.updated_at,
         )
 
         return columns, data
@@ -107,7 +125,7 @@ class TestPort(network_fakes.TestNetworkV2):
 
 class TestCreatePort(TestPort):
 
-    _port = network_fakes.FakePort.create_one_port()
+    _port = network_fakes.create_one_port()
     columns, data = TestPort._get_common_cols_data(_port)
 
     def setUp(self):
@@ -115,7 +133,7 @@ class TestCreatePort(TestPort):
 
         self.network.create_port = mock.Mock(return_value=self._port)
         self.network.set_tags = mock.Mock(return_value=None)
-        fake_net = network_fakes.FakeNetwork.create_one_network({
+        fake_net = network_fakes.create_one_network({
             'id': self._port.network_id,
         })
         self.network.find_network = mock.Mock(return_value=fake_net)
@@ -146,8 +164,8 @@ class TestCreatePort(TestPort):
         })
         self.assertFalse(self.network.set_tags.called)
 
-        self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.data, data)
 
     def test_create_full_options(self):
         arglist = [
@@ -204,8 +222,8 @@ class TestCreatePort(TestPort):
             'name': 'test-port',
         })
 
-        self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.data, data)
 
     def test_create_invalid_json_binding_profile(self):
         arglist = [
@@ -255,8 +273,8 @@ class TestCreatePort(TestPort):
             'name': 'test-port',
         })
 
-        self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_security_group(self):
         secgroup = network_fakes.FakeSecurityGroup.create_one_security_group()
@@ -284,8 +302,8 @@ class TestCreatePort(TestPort):
             'name': 'test-port',
         })
 
-        self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.data, data)
 
     def test_create_port_with_dns_name(self):
         arglist = [
@@ -310,8 +328,8 @@ class TestCreatePort(TestPort):
             'name': 'test-port',
         })
 
-        self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_security_groups(self):
         sg_1 = network_fakes.FakeSecurityGroup.create_one_security_group()
@@ -340,8 +358,8 @@ class TestCreatePort(TestPort):
             'name': 'test-port',
         })
 
-        self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_no_security_groups(self):
         arglist = [
@@ -366,8 +384,8 @@ class TestCreatePort(TestPort):
             'name': 'test-port',
         })
 
-        self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_no_fixed_ips(self):
         arglist = [
@@ -392,8 +410,8 @@ class TestCreatePort(TestPort):
             'name': 'test-port',
         })
 
-        self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.data, data)
 
     def test_create_port_with_allowed_address_pair_ipaddr(self):
         pairs = [{'ip_address': '192.168.1.123'},
@@ -422,8 +440,8 @@ class TestCreatePort(TestPort):
             'name': 'test-port',
         })
 
-        self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.data, data)
 
     def test_create_port_with_allowed_address_pair(self):
         pairs = [{'ip_address': '192.168.1.123',
@@ -458,8 +476,8 @@ class TestCreatePort(TestPort):
             'name': 'test-port',
         })
 
-        self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.data, data)
 
     def test_create_port_with_qos(self):
         qos_policy = network_fakes.FakeNetworkQosPolicy.create_one_qos_policy()
@@ -486,8 +504,8 @@ class TestCreatePort(TestPort):
             'name': 'test-port',
         })
 
-        self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.data, data)
 
     def test_create_port_security_enabled(self):
         arglist = [
@@ -595,8 +613,8 @@ class TestCreatePort(TestPort):
             else:
                 self.assertFalse(self.network.set_tags.called)
 
-        self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_tags(self):
         self._test_create_with_tag(add_tags=True, add_tags_in_post=True)
@@ -638,8 +656,8 @@ class TestCreatePort(TestPort):
             'name': 'test-port',
         })
 
-        self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_uplink_status_propagation_enabled(self):
         self._test_create_with_uplink_status_propagation(enable=True)
@@ -718,8 +736,8 @@ class TestCreatePort(TestPort):
             create_args['numa_affinity_policy'] = numa_affinity_policy
         self.network.create_port.assert_called_once_with(**create_args)
 
-        self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_numa_affinity_policy_required(self):
         self._test_create_with_numa_affinity_policy(policy='required')
@@ -733,17 +751,44 @@ class TestCreatePort(TestPort):
     def test_create_with_numa_affinity_policy_null(self):
         self._test_create_with_numa_affinity_policy()
 
+    def test_create_with_device_profile(self):
+        arglist = [
+            '--network', self._port.network_id,
+            '--device-profile', 'cyborg_device_profile_1',
+            'test-port',
+        ]
+
+        verifylist = [
+            ('network', self._port.network_id,),
+            ('device_profile', self._port.device_profile,),
+            ('name', 'test-port'),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = (self.cmd.take_action(parsed_args))
+
+        create_args = {
+            'admin_state_up': True,
+            'network_id': self._port.network_id,
+            'name': 'test-port',
+            'device_profile': 'cyborg_device_profile_1',
+        }
+        self.network.create_port.assert_called_once_with(**create_args)
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.data, data)
+
 
 class TestDeletePort(TestPort):
 
     # Ports to delete.
-    _ports = network_fakes.FakePort.create_ports(count=2)
+    _ports = network_fakes.create_ports(count=2)
 
     def setUp(self):
         super(TestDeletePort, self).setUp()
 
         self.network.delete_port = mock.Mock(return_value=None)
-        self.network.find_port = network_fakes.FakePort.get_ports(
+        self.network.find_port = network_fakes.get_ports(
             ports=self._ports)
         # Get the command object to test
         self.cmd = port.DeletePort(self.app, self.namespace)
@@ -815,7 +860,7 @@ class TestDeletePort(TestPort):
 
 class TestListPort(TestPort):
 
-    _ports = network_fakes.FakePort.create_ports(count=3)
+    _ports = network_fakes.create_ports(count=3)
 
     columns = (
         'ID',
@@ -868,7 +913,7 @@ class TestListPort(TestPort):
         fake_router = network_fakes.FakeRouter.create_one_router({
             'id': 'fake-router-id',
         })
-        fake_network = network_fakes.FakeNetwork.create_one_network({
+        fake_network = network_fakes.create_one_network({
             'id': 'fake-network-id',
         })
         self.network.find_router = mock.Mock(return_value=fake_router)
@@ -883,9 +928,10 @@ class TestListPort(TestPort):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.ports.assert_called_once_with()
+        self.network.ports.assert_called_once_with(
+            fields=LIST_FIELDS_TO_RETRIEVE)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_router_opt(self):
         arglist = [
@@ -901,10 +947,11 @@ class TestListPort(TestPort):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.ports.assert_called_once_with(**{
-            'device_id': 'fake-router-id'
+            'device_id': 'fake-router-id',
+            'fields': LIST_FIELDS_TO_RETRIEVE,
         })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     @mock.patch.object(utils, 'find_resource')
     def test_port_list_with_server_option(self, mock_find):
@@ -921,10 +968,11 @@ class TestListPort(TestPort):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
         self.network.ports.assert_called_once_with(
-            device_id=fake_server.id)
+            device_id=fake_server.id,
+            fields=LIST_FIELDS_TO_RETRIEVE)
         mock_find.assert_called_once_with(mock.ANY, 'fake-server-name')
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_device_id_opt(self):
         arglist = [
@@ -940,10 +988,11 @@ class TestListPort(TestPort):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.ports.assert_called_once_with(**{
-            'device_id': self._ports[0].device_id
+            'device_id': self._ports[0].device_id,
+            'fields': LIST_FIELDS_TO_RETRIEVE,
         })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_device_owner_opt(self):
         arglist = [
@@ -959,10 +1008,11 @@ class TestListPort(TestPort):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.ports.assert_called_once_with(**{
-            'device_owner': self._ports[0].device_owner
+            'device_owner': self._ports[0].device_owner,
+            'fields': LIST_FIELDS_TO_RETRIEVE,
         })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_all_opt(self):
         arglist = [
@@ -987,10 +1037,11 @@ class TestListPort(TestPort):
             'device_owner': self._ports[0].device_owner,
             'device_id': 'fake-router-id',
             'network_id': 'fake-network-id',
-            'mac_address': self._ports[0].mac_address
+            'mac_address': self._ports[0].mac_address,
+            'fields': LIST_FIELDS_TO_RETRIEVE,
         })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_mac_address_opt(self):
         arglist = [
@@ -1006,10 +1057,11 @@ class TestListPort(TestPort):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.ports.assert_called_once_with(**{
-            'mac_address': self._ports[0].mac_address
+            'mac_address': self._ports[0].mac_address,
+            'fields': LIST_FIELDS_TO_RETRIEVE,
         })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_fixed_ip_opt_ip_address(self):
         ip_address = self._ports[0].fixed_ips[0]['ip_address']
@@ -1025,9 +1077,11 @@ class TestListPort(TestPort):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.ports.assert_called_once_with(**{
-            'fixed_ips': ['ip_address=%s' % ip_address]})
+            'fixed_ips': ['ip_address=%s' % ip_address],
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_fixed_ip_opt_ip_address_substr(self):
         ip_address_ss = self._ports[0].fixed_ips[0]['ip_address'][:-1]
@@ -1043,9 +1097,11 @@ class TestListPort(TestPort):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.ports.assert_called_once_with(**{
-            'fixed_ips': ['ip_address_substr=%s' % ip_address_ss]})
+            'fixed_ips': ['ip_address_substr=%s' % ip_address_ss],
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_fixed_ip_opt_subnet_id(self):
         subnet_id = self._ports[0].fixed_ips[0]['subnet_id']
@@ -1063,9 +1119,11 @@ class TestListPort(TestPort):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.ports.assert_called_once_with(**{
-            'fixed_ips': ['subnet_id=%s' % subnet_id]})
+            'fixed_ips': ['subnet_id=%s' % subnet_id],
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_fixed_ip_opts(self):
         subnet_id = self._ports[0].fixed_ips[0]['subnet_id']
@@ -1087,9 +1145,11 @@ class TestListPort(TestPort):
 
         self.network.ports.assert_called_once_with(**{
             'fixed_ips': ['subnet_id=%s' % subnet_id,
-                          'ip_address=%s' % ip_address]})
+                          'ip_address=%s' % ip_address],
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_fixed_ips(self):
         subnet_id = self._ports[0].fixed_ips[0]['subnet_id']
@@ -1103,17 +1163,21 @@ class TestListPort(TestPort):
                           {'ip-address': ip_address}])
         ]
 
-        self.fake_subnet = network_fakes.FakeSubnet.create_one_subnet(
-            {'id': subnet_id})
+        self.fake_subnet = network_fakes.FakeSubnet.create_one_subnet({
+            'id': subnet_id,
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        })
         self.network.find_subnet = mock.Mock(return_value=self.fake_subnet)
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.ports.assert_called_once_with(**{
             'fixed_ips': ['subnet_id=%s' % subnet_id,
-                          'ip_address=%s' % ip_address]})
+                          'ip_address=%s' % ip_address],
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_list_port_with_long(self):
         arglist = [
@@ -1128,9 +1192,10 @@ class TestListPort(TestPort):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.ports.assert_called_once_with()
+        self.network.ports.assert_called_once_with(
+            fields=LIST_FIELDS_TO_RETRIEVE + LIST_FIELDS_TO_RETRIEVE_LONG)
         self.assertEqual(self.columns_long, columns)
-        self.assertListItemEqual(self.data_long, list(data))
+        self.assertCountEqual(self.data_long, list(data))
 
     def test_port_list_host(self):
         arglist = [
@@ -1142,11 +1207,14 @@ class TestListPort(TestPort):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        filters = {'binding:host_id': 'foobar'}
+        filters = {
+            'binding:host_id': 'foobar',
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        }
 
         self.network.ports.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_project(self):
         project = identity_fakes.FakeProject.create_one_project()
@@ -1160,11 +1228,14 @@ class TestListPort(TestPort):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        filters = {'tenant_id': project.id, 'project_id': project.id}
+        filters = {
+            'project_id': project.id,
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        }
 
         self.network.ports.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_project_domain(self):
         project = identity_fakes.FakeProject.create_one_project()
@@ -1180,11 +1251,34 @@ class TestListPort(TestPort):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        filters = {'tenant_id': project.id, 'project_id': project.id}
+        filters = {
+            'project_id': project.id,
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        }
 
         self.network.ports.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
+
+    def test_port_list_name(self):
+        test_name = "fakename"
+        arglist = [
+            '--name', test_name,
+        ]
+        verifylist = [
+            ('name', test_name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+        filters = {
+            'name': test_name,
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        }
+
+        self.network.ports.assert_called_once_with(**filters)
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.data, list(data))
 
     def test_list_with_tag_options(self):
         arglist = [
@@ -1206,15 +1300,36 @@ class TestListPort(TestPort):
             **{'tags': 'red,blue',
                'any_tags': 'red,green',
                'not_tags': 'orange,yellow',
-               'not_any_tags': 'black,white'}
+               'not_any_tags': 'black,white',
+               'fields': LIST_FIELDS_TO_RETRIEVE}
         )
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
+
+    def test_port_list_security_group(self):
+        arglist = [
+            '--security-group', 'sg-id1',
+            '--security-group', 'sg-id2',
+        ]
+        verifylist = [
+            ('security_groups', ['sg-id1', 'sg-id2']),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+        filters = {
+            'security_groups': ['sg-id1', 'sg-id2'],
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        }
+
+        self.network.ports.assert_called_once_with(**filters)
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.data, list(data))
 
 
 class TestSetPort(TestPort):
 
-    _port = network_fakes.FakePort.create_one_port({'tags': ['green', 'red']})
+    _port = network_fakes.create_one_port({'tags': ['green', 'red']})
 
     def setUp(self):
         super(TestSetPort, self).setUp()
@@ -1242,7 +1357,7 @@ class TestSetPort(TestPort):
         self.assertIsNone(result)
 
     def test_set_port_fixed_ip(self):
-        _testport = network_fakes.FakePort.create_one_port(
+        _testport = network_fakes.create_one_port(
             {'fixed_ips': [{'ip_address': '0.0.0.1'}]})
         self.network.find_port = mock.Mock(return_value=_testport)
         arglist = [
@@ -1266,7 +1381,7 @@ class TestSetPort(TestPort):
         self.assertIsNone(result)
 
     def test_set_port_fixed_ip_clear(self):
-        _testport = network_fakes.FakePort.create_one_port(
+        _testport = network_fakes.create_one_port(
             {'fixed_ips': [{'ip_address': '0.0.0.1'}]})
         self.network.find_port = mock.Mock(return_value=_testport)
         arglist = [
@@ -1309,7 +1424,7 @@ class TestSetPort(TestPort):
         self.assertIsNone(result)
 
     def test_set_port_overwrite_binding_profile(self):
-        _testport = network_fakes.FakePort.create_one_port(
+        _testport = network_fakes.create_one_port(
             {'binding_profile': {'lok_i': 'visi_on'}})
         self.network.find_port = mock.Mock(return_value=_testport)
         arglist = [
@@ -1331,7 +1446,7 @@ class TestSetPort(TestPort):
         self.assertIsNone(result)
 
     def test_overwrite_mac_address(self):
-        _testport = network_fakes.FakePort.create_one_port(
+        _testport = network_fakes.create_one_port(
             {'mac_address': '11:22:33:44:55:66'})
         self.network.find_port = mock.Mock(return_value=_testport)
         arglist = [
@@ -1475,7 +1590,7 @@ class TestSetPort(TestPort):
         sg_2 = network_fakes.FakeSecurityGroup.create_one_security_group()
         sg_3 = network_fakes.FakeSecurityGroup.create_one_security_group()
         self.network.find_security_group = mock.Mock(side_effect=[sg_2, sg_3])
-        _testport = network_fakes.FakePort.create_one_port(
+        _testport = network_fakes.create_one_port(
             {'security_group_ids': [sg_1.id]})
         self.network.find_port = mock.Mock(return_value=_testport)
         arglist = [
@@ -1517,7 +1632,7 @@ class TestSetPort(TestPort):
     def test_set_port_security_group_replace(self):
         sg1 = network_fakes.FakeSecurityGroup.create_one_security_group()
         sg2 = network_fakes.FakeSecurityGroup.create_one_security_group()
-        _testport = network_fakes.FakePort.create_one_port(
+        _testport = network_fakes.create_one_port(
             {'security_group_ids': [sg1.id]})
         self.network.find_port = mock.Mock(return_value=_testport)
         self.network.find_security_group = mock.Mock(return_value=sg2)
@@ -1559,7 +1674,7 @@ class TestSetPort(TestPort):
         self.assertIsNone(result)
 
     def test_set_port_append_allowed_address_pair(self):
-        _testport = network_fakes.FakePort.create_one_port(
+        _testport = network_fakes.create_one_port(
             {'allowed_address_pairs': [{'ip_address': '192.168.1.123'}]})
         self.network.find_port = mock.Mock(return_value=_testport)
         arglist = [
@@ -1582,7 +1697,7 @@ class TestSetPort(TestPort):
         self.assertIsNone(result)
 
     def test_set_port_overwrite_allowed_address_pair(self):
-        _testport = network_fakes.FakePort.create_one_port(
+        _testport = network_fakes.create_one_port(
             {'allowed_address_pairs': [{'ip_address': '192.168.1.123'}]})
         self.network.find_port = mock.Mock(return_value=_testport)
         arglist = [
@@ -1624,6 +1739,27 @@ class TestSetPort(TestPort):
         self.network.update_port.assert_called_once_with(self._port, **attrs)
         self.assertIsNone(result)
 
+    def test_set_port_extra_dhcp_option(self):
+        arglist = [
+            '--extra-dhcp-option', 'name=foo,value=bar',
+            self._port.name,
+        ]
+        verifylist = [
+            ('extra_dhcp_options', [{'name': 'foo',
+                                     'value': 'bar'}]),
+            ('port', self._port.name),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        result = self.cmd.take_action(parsed_args)
+
+        attrs = {
+            'extra_dhcp_opts': [{'opt_name': 'foo',
+                                 'opt_value': 'bar'}],
+        }
+        self.network.update_port.assert_called_once_with(self._port, **attrs)
+        self.assertIsNone(result)
+
     def test_set_port_security_enabled(self):
         arglist = [
             '--enable-port-security',
@@ -1663,7 +1799,7 @@ class TestSetPort(TestPort):
     def test_set_port_with_qos(self):
         qos_policy = network_fakes.FakeNetworkQosPolicy.create_one_qos_policy()
         self.network.find_qos_policy = mock.Mock(return_value=qos_policy)
-        _testport = network_fakes.FakePort.create_one_port(
+        _testport = network_fakes.create_one_port(
             {'qos_policy_id': None})
         self.network.find_port = mock.Mock(return_value=_testport)
         arglist = [
@@ -1685,7 +1821,7 @@ class TestSetPort(TestPort):
         self.assertIsNone(result)
 
     def test_set_port_data_plane_status(self):
-        _testport = network_fakes.FakePort.create_one_port(
+        _testport = network_fakes.create_one_port(
             {'data_plane_status': None})
         self.network.find_port = mock.Mock(return_value=_testport)
         arglist = [
@@ -1776,7 +1912,7 @@ class TestSetPort(TestPort):
 class TestShowPort(TestPort):
 
     # The port to show.
-    _port = network_fakes.FakePort.create_one_port()
+    _port = network_fakes.create_one_port()
     columns, data = TestPort._get_common_cols_data(_port)
 
     def setUp(self):
@@ -1808,15 +1944,15 @@ class TestShowPort(TestPort):
         self.network.find_port.assert_called_once_with(
             self._port.name, ignore_missing=False)
 
-        self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertEqual(set(self.columns), set(columns))
+        self.assertCountEqual(self.data, data)
 
 
 class TestUnsetPort(TestPort):
 
     def setUp(self):
         super(TestUnsetPort, self).setUp()
-        self._testport = network_fakes.FakePort.create_one_port(
+        self._testport = network_fakes.create_one_port(
             {'fixed_ips': [{'subnet_id': '042eb10a-3a18-4658-ab-cf47c8d03152',
                             'ip_address': '0.0.0.1'},
                            {'subnet_id': '042eb10a-3a18-4658-ab-cf47c8d03152',
@@ -1838,6 +1974,7 @@ class TestUnsetPort(TestPort):
             'subnet=042eb10a-3a18-4658-ab-cf47c8d03152,ip-address=1.0.0.0',
             '--binding-profile', 'Superman',
             '--qos-policy',
+            '--host',
             self._testport.name,
         ]
         verifylist = [
@@ -1846,6 +1983,7 @@ class TestUnsetPort(TestPort):
                 'ip-address': '1.0.0.0'}]),
             ('binding_profile', ['Superman']),
             ('qos_policy', True),
+            ('host', True)
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -1856,7 +1994,8 @@ class TestUnsetPort(TestPort):
                 'subnet_id': '042eb10a-3a18-4658-ab-cf47c8d03152',
                 'ip_address': '0.0.0.1'}],
             'binding:profile': {'batman': 'Joker'},
-            'qos_policy_id': None
+            'qos_policy_id': None,
+            'binding:host_id': None
         }
         self.network.update_port.assert_called_once_with(
             self._testport, **attrs)
@@ -1897,7 +2036,7 @@ class TestUnsetPort(TestPort):
     def test_unset_security_group(self):
         _fake_sg1 = network_fakes.FakeSecurityGroup.create_one_security_group()
         _fake_sg2 = network_fakes.FakeSecurityGroup.create_one_security_group()
-        _fake_port = network_fakes.FakePort.create_one_port(
+        _fake_port = network_fakes.create_one_port(
             {'security_group_ids': [_fake_sg1.id, _fake_sg2.id]})
         self.network.find_port = mock.Mock(return_value=_fake_port)
         self.network.find_security_group = mock.Mock(return_value=_fake_sg2)
@@ -1922,7 +2061,7 @@ class TestUnsetPort(TestPort):
     def test_unset_port_security_group_not_existent(self):
         _fake_sg1 = network_fakes.FakeSecurityGroup.create_one_security_group()
         _fake_sg2 = network_fakes.FakeSecurityGroup.create_one_security_group()
-        _fake_port = network_fakes.FakePort.create_one_port(
+        _fake_port = network_fakes.create_one_port(
             {'security_group_ids': [_fake_sg1.id]})
         self.network.find_security_group = mock.Mock(return_value=_fake_sg2)
         arglist = [
@@ -1939,7 +2078,7 @@ class TestUnsetPort(TestPort):
                           parsed_args)
 
     def test_unset_port_allowed_address_pair(self):
-        _fake_port = network_fakes.FakePort.create_one_port(
+        _fake_port = network_fakes.create_one_port(
             {'allowed_address_pairs': [{'ip_address': '192.168.1.123'}]})
         self.network.find_port = mock.Mock(return_value=_fake_port)
         arglist = [
@@ -1961,7 +2100,7 @@ class TestUnsetPort(TestPort):
         self.assertIsNone(result)
 
     def test_unset_port_allowed_address_pair_not_existent(self):
-        _fake_port = network_fakes.FakePort.create_one_port(
+        _fake_port = network_fakes.create_one_port(
             {'allowed_address_pairs': [{'ip_address': '192.168.1.123'}]})
         self.network.find_port = mock.Mock(return_value=_fake_port)
         arglist = [
@@ -1978,7 +2117,7 @@ class TestUnsetPort(TestPort):
                           parsed_args)
 
     def test_unset_port_data_plane_status(self):
-        _fake_port = network_fakes.FakePort.create_one_port(
+        _fake_port = network_fakes.create_one_port(
             {'data_plane_status': 'ACTIVE'})
         self.network.find_port = mock.Mock(return_value=_fake_port)
         arglist = [
@@ -2029,7 +2168,7 @@ class TestUnsetPort(TestPort):
         self._test_unset_tags(with_tags=False)
 
     def test_unset_numa_affinity_policy(self):
-        _fake_port = network_fakes.FakePort.create_one_port(
+        _fake_port = network_fakes.create_one_port(
             {'numa_affinity_policy': 'required'})
         self.network.find_port = mock.Mock(return_value=_fake_port)
         arglist = [
