@@ -135,7 +135,7 @@ class TestVolumeCreate(TestVolume):
             None,
         )
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_volume_create_options(self):
         arglist = [
@@ -179,7 +179,7 @@ class TestVolumeCreate(TestVolume):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_volume_create_user_project_id(self):
         # Return a project
@@ -226,7 +226,7 @@ class TestVolumeCreate(TestVolume):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_volume_create_user_project_name(self):
         # Return a project
@@ -273,7 +273,7 @@ class TestVolumeCreate(TestVolume):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_volume_create_properties(self):
         arglist = [
@@ -314,10 +314,10 @@ class TestVolumeCreate(TestVolume):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_volume_create_image_id(self):
-        image = image_fakes.FakeImage.create_one_image()
+        image = image_fakes.create_one_image()
         self.images_mock.get.return_value = image
 
         arglist = [
@@ -357,10 +357,10 @@ class TestVolumeCreate(TestVolume):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_volume_create_image_name(self):
-        image = image_fakes.FakeImage.create_one_image()
+        image = image_fakes.create_one_image()
         self.images_mock.get.return_value = image
 
         arglist = [
@@ -400,7 +400,7 @@ class TestVolumeCreate(TestVolume):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_volume_create_with_source(self):
         self.volumes_mock.get.return_value = self.new_volume
@@ -430,7 +430,7 @@ class TestVolumeCreate(TestVolume):
             None,
         )
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_volume_create_with_bootable_and_readonly(self):
         arglist = [
@@ -468,7 +468,7 @@ class TestVolumeCreate(TestVolume):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
         self.volumes_mock.set_bootable.assert_called_with(
             self.new_volume.id, True)
         self.volumes_mock.update_readonly_flag.assert_called_with(
@@ -510,7 +510,7 @@ class TestVolumeCreate(TestVolume):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
         self.volumes_mock.set_bootable.assert_called_with(
             self.new_volume.id, False)
         self.volumes_mock.update_readonly_flag.assert_called_with(
@@ -562,7 +562,7 @@ class TestVolumeCreate(TestVolume):
 
         self.assertEqual(2, mock_error.call_count)
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
         self.volumes_mock.set_bootable.assert_called_with(
             self.new_volume.id, True)
         self.volumes_mock.update_readonly_flag.assert_called_with(
@@ -765,7 +765,7 @@ class TestVolumeList(TestVolume):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.datalist, tuple(data))
+        self.assertCountEqual(self.datalist, tuple(data))
 
     def test_volume_list_name(self):
         arglist = [
@@ -782,7 +782,7 @@ class TestVolumeList(TestVolume):
 
         columns, data = self.cmd.take_action(parsed_args)
         self.assertEqual(self.columns, tuple(columns))
-        self.assertListItemEqual(self.datalist, tuple(data))
+        self.assertCountEqual(self.datalist, tuple(data))
 
     def test_volume_list_status(self):
         arglist = [
@@ -799,7 +799,7 @@ class TestVolumeList(TestVolume):
 
         columns, data = self.cmd.take_action(parsed_args)
         self.assertEqual(self.columns, tuple(columns))
-        self.assertListItemEqual(self.datalist, tuple(data))
+        self.assertCountEqual(self.datalist, tuple(data))
 
     def test_volume_list_all_projects(self):
         arglist = [
@@ -816,7 +816,7 @@ class TestVolumeList(TestVolume):
 
         columns, data = self.cmd.take_action(parsed_args)
         self.assertEqual(self.columns, tuple(columns))
-        self.assertListItemEqual(self.datalist, tuple(data))
+        self.assertCountEqual(self.datalist, tuple(data))
 
     def test_volume_list_long(self):
         arglist = [
@@ -856,11 +856,12 @@ class TestVolumeList(TestVolume):
             volume.AttachmentsColumn(self._volume.attachments),
             format_columns.DictColumn(self._volume.metadata),
         ), )
-        self.assertListItemEqual(datalist, tuple(data))
+        self.assertCountEqual(datalist, tuple(data))
 
-    def test_volume_list_with_limit(self):
+    def test_volume_list_with_limit_and_offset(self):
         arglist = [
             '--limit', '2',
+            '--offset', '5',
         ]
         verifylist = [
             ('long', False),
@@ -868,6 +869,7 @@ class TestVolumeList(TestVolume):
             ('name', None),
             ('status', None),
             ('limit', 2),
+            ('offset', 5),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -876,12 +878,14 @@ class TestVolumeList(TestVolume):
         self.volumes_mock.list.assert_called_once_with(
             limit=2,
             search_opts={
+                'offset': 5,
                 'status': None,
                 'display_name': None,
-                'all_tenants': False, }
+                'all_tenants': False,
+            },
         )
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.datalist, tuple(data))
+        self.assertCountEqual(self.datalist, tuple(data))
 
     def test_volume_list_negative_limit(self):
         arglist = [
@@ -1272,7 +1276,7 @@ class TestVolumeShow(TestVolume):
         self.volumes_mock.get.assert_called_with(self._volume.id)
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_volume_show_backward_compatibility(self):
         arglist = [
