@@ -58,7 +58,8 @@ class TestTypeCreate(TestType):
     def setUp(self):
         super(TestTypeCreate, self).setUp()
 
-        self.new_volume_type = volume_fakes.FakeType.create_one_type()
+        self.new_volume_type = \
+            volume_fakes.FakeVolumeType.create_one_volume_type()
         self.data = (
             self.new_volume_type.description,
             self.new_volume_type.id,
@@ -93,7 +94,7 @@ class TestTypeCreate(TestType):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_type_create_private(self):
         arglist = [
@@ -119,7 +120,7 @@ class TestTypeCreate(TestType):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_public_type_create_with_project(self):
         arglist = [
@@ -143,11 +144,12 @@ class TestTypeCreate(TestType):
             'key_size': '128',
             'control_location': 'front-end',
         }
-        encryption_type = volume_fakes.FakeType.create_one_encryption_type(
-            attrs=encryption_info
-        )
-        self.new_volume_type = volume_fakes.FakeType.create_one_type(
-            attrs={'encryption': encryption_info})
+        encryption_type = \
+            volume_fakes.FakeVolumeType.create_one_encryption_volume_type(
+                attrs=encryption_info)
+        self.new_volume_type = \
+            volume_fakes.FakeVolumeType.create_one_volume_type(
+                attrs={'encryption': encryption_info})
         self.types_mock.create.return_value = self.new_volume_type
         self.encryption_types_mock.create.return_value = encryption_type
         encryption_columns = (
@@ -196,17 +198,17 @@ class TestTypeCreate(TestType):
             body,
         )
         self.assertEqual(encryption_columns, columns)
-        self.assertItemEqual(encryption_data, data)
+        self.assertCountEqual(encryption_data, data)
 
 
 class TestTypeDelete(TestType):
 
-    volume_types = volume_fakes.FakeType.create_types(count=2)
+    volume_types = volume_fakes.FakeVolumeType.create_volume_types(count=2)
 
     def setUp(self):
         super(TestTypeDelete, self).setUp()
 
-        self.types_mock.get = volume_fakes.FakeType.get_types(
+        self.types_mock.get = volume_fakes.FakeVolumeType.get_volume_types(
             self.volume_types)
         self.types_mock.delete.return_value = None
 
@@ -276,7 +278,7 @@ class TestTypeDelete(TestType):
 
 class TestTypeList(TestType):
 
-    volume_types = volume_fakes.FakeType.create_types()
+    volume_types = volume_fakes.FakeVolumeType.create_volume_types()
 
     columns = [
         "ID",
@@ -330,7 +332,7 @@ class TestTypeList(TestType):
         columns, data = self.cmd.take_action(parsed_args)
         self.types_mock.list.assert_called_once_with(is_public=None)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_type_list_with_options(self):
         arglist = [
@@ -348,7 +350,7 @@ class TestTypeList(TestType):
         columns, data = self.cmd.take_action(parsed_args)
         self.types_mock.list.assert_called_once_with(is_public=True)
         self.assertEqual(self.columns_long, columns)
-        self.assertListItemEqual(self.data_long, list(data))
+        self.assertCountEqual(self.data_long, list(data))
 
     def test_type_list_with_private_option(self):
         arglist = [
@@ -365,7 +367,7 @@ class TestTypeList(TestType):
         columns, data = self.cmd.take_action(parsed_args)
         self.types_mock.list.assert_called_once_with(is_public=False)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_type_list_with_default_option(self):
         arglist = [
@@ -383,11 +385,12 @@ class TestTypeList(TestType):
         columns, data = self.cmd.take_action(parsed_args)
         self.types_mock.default.assert_called_once_with()
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data_with_default_type, list(data))
+        self.assertCountEqual(self.data_with_default_type, list(data))
 
     def test_type_list_with_encryption(self):
-        encryption_type = volume_fakes.FakeType.create_one_encryption_type(
-            attrs={'volume_type_id': self.volume_types[0].id})
+        encryption_type = \
+            volume_fakes.FakeVolumeType.create_one_encryption_volume_type(
+                attrs={'volume_type_id': self.volume_types[0].id})
         encryption_info = {
             'provider': 'LuksEncryptor',
             'cipher': None,
@@ -427,13 +430,13 @@ class TestTypeList(TestType):
         self.encryption_types_mock.list.assert_called_once_with()
         self.types_mock.list.assert_called_once_with(is_public=None)
         self.assertEqual(encryption_columns, columns)
-        self.assertListItemEqual(encryption_data, list(data))
+        self.assertCountEqual(encryption_data, list(data))
 
 
 class TestTypeSet(TestType):
 
     project = identity_fakes.FakeProject.create_one_project()
-    volume_type = volume_fakes.FakeType.create_one_type(
+    volume_type = volume_fakes.FakeVolumeType.create_one_volume_type(
         methods={'set_keys': None})
 
     def setUp(self):
@@ -684,7 +687,7 @@ class TestTypeShow(TestType):
     def setUp(self):
         super(TestTypeShow, self).setUp()
 
-        self.volume_type = volume_fakes.FakeType.create_one_type()
+        self.volume_type = volume_fakes.FakeVolumeType.create_one_volume_type()
         self.data = (
             None,
             self.volume_type.description,
@@ -713,7 +716,7 @@ class TestTypeShow(TestType):
         self.types_mock.get.assert_called_with(self.volume_type.id)
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_type_show_with_access(self):
         arglist = [
@@ -724,7 +727,7 @@ class TestTypeShow(TestType):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        private_type = volume_fakes.FakeType.create_one_type(
+        private_type = volume_fakes.FakeVolumeType.create_one_volume_type(
             attrs={'is_public': False})
         type_access_list = volume_fakes.FakeTypeAccess.create_one_type_access()
         with mock.patch.object(self.types_mock, 'get',
@@ -746,7 +749,7 @@ class TestTypeShow(TestType):
             private_type.name,
             format_columns.DictColumn(private_type.extra_specs)
         )
-        self.assertItemEqual(private_type_data, data)
+        self.assertCountEqual(private_type_data, data)
 
     def test_type_show_with_list_access_exec(self):
         arglist = [
@@ -757,7 +760,7 @@ class TestTypeShow(TestType):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        private_type = volume_fakes.FakeType.create_one_type(
+        private_type = volume_fakes.FakeVolumeType.create_one_volume_type(
             attrs={'is_public': False})
         with mock.patch.object(self.types_mock, 'get',
                                return_value=private_type):
@@ -778,17 +781,18 @@ class TestTypeShow(TestType):
             private_type.name,
             format_columns.DictColumn(private_type.extra_specs)
         )
-        self.assertItemEqual(private_type_data, data)
+        self.assertCountEqual(private_type_data, data)
 
     def test_type_show_with_encryption(self):
-        encryption_type = volume_fakes.FakeType.create_one_encryption_type()
+        encryption_type = \
+            volume_fakes.FakeVolumeType.create_one_encryption_volume_type()
         encryption_info = {
             'provider': 'LuksEncryptor',
             'cipher': None,
             'key_size': None,
             'control_location': 'front-end',
         }
-        self.volume_type = volume_fakes.FakeType.create_one_type(
+        self.volume_type = volume_fakes.FakeVolumeType.create_one_volume_type(
             attrs={'encryption': encryption_info})
         self.types_mock.get.return_value = self.volume_type
         self.encryption_types_mock.get.return_value = encryption_type
@@ -824,13 +828,13 @@ class TestTypeShow(TestType):
         self.types_mock.get.assert_called_with(self.volume_type.id)
         self.encryption_types_mock.get.assert_called_with(self.volume_type.id)
         self.assertEqual(encryption_columns, columns)
-        self.assertItemEqual(encryption_data, data)
+        self.assertCountEqual(encryption_data, data)
 
 
 class TestTypeUnset(TestType):
 
     project = identity_fakes.FakeProject.create_one_project()
-    volume_type = volume_fakes.FakeType.create_one_type(
+    volume_type = volume_fakes.FakeVolumeType.create_one_volume_type(
         methods={'unset_keys': None})
 
     def setUp(self):
@@ -932,7 +936,7 @@ class TestTypeUnset(TestType):
 class TestColumns(TestType):
 
     def test_encryption_info_column_with_info(self):
-        fake_volume_type = volume_fakes.FakeType.create_one_type()
+        fake_volume_type = volume_fakes.FakeVolumeType.create_one_volume_type()
         type_id = fake_volume_type.id
 
         encryption_info = {
@@ -948,7 +952,7 @@ class TestColumns(TestType):
         self.assertEqual(encryption_info, col.machine_readable())
 
     def test_encryption_info_column_without_info(self):
-        fake_volume_type = volume_fakes.FakeType.create_one_type()
+        fake_volume_type = volume_fakes.FakeVolumeType.create_one_volume_type()
         type_id = fake_volume_type.id
 
         col = volume_type.EncryptionInfoColumn(type_id, {})
